@@ -391,12 +391,31 @@ impl<'a> AnonymousListBuilder<'a> {
         }
     }
 
+    pub fn append_opt_array(&mut self, opt_s: Option<&'a dyn Array>) {
+        match opt_s {
+            Some(s) => self.append_array(s),
+            None => {
+                self.append_null();
+            }
+        }
+    }
+
+    pub fn append_array(&mut self, arr: &'a dyn Array) {
+        self.builder.push(arr)
+    }
+
     pub fn append_null(&mut self) {
         self.builder.push_null();
     }
 
     pub fn append_series(&mut self, s: &'a Series) {
-        self.builder.push_multiple(s.chunks());
+        match s.dtype() {
+            #[cfg(feature = "dtype-struct")]
+            DataType::Struct(_) => self.builder.push(&**s.array_ref(0)),
+            _ => {
+                self.builder.push_multiple(s.chunks());
+            }
+        }
     }
 
     pub fn finish(self) -> ListChunked {
