@@ -1,5 +1,6 @@
 use crate::chunked_array::builder::get_list_builder;
 use crate::prelude::*;
+use crate::series::ops::NullBehavior;
 use polars_arrow::kernels::list::sublist_get;
 use polars_arrow::prelude::ValueSize;
 use std::convert::TryFrom;
@@ -137,17 +138,49 @@ impl ListChunked {
         self.try_apply_amortized(|s| s.as_ref().unique())
     }
 
-    pub fn lst_lengths(&self) -> UInt32Chunked {
+    pub fn lst_arg_min(&self) -> IdxCa {
+        let mut out: IdxCa = self
+            .amortized_iter()
+            .map(|opt_s| opt_s.and_then(|s| s.as_ref().arg_min().map(|idx| idx as IdxSize)))
+            .collect_trusted();
+        out.rename(self.name());
+        out
+    }
+
+    pub fn lst_arg_max(&self) -> IdxCa {
+        let mut out: IdxCa = self
+            .amortized_iter()
+            .map(|opt_s| opt_s.and_then(|s| s.as_ref().arg_max().map(|idx| idx as IdxSize)))
+            .collect_trusted();
+        out.rename(self.name());
+        out
+    }
+
+    #[cfg(feature = "diff")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "diff")))]
+    pub fn lst_diff(&self, n: usize, null_behavior: NullBehavior) -> ListChunked {
+        self.apply_amortized(|s| s.as_ref().diff(n, null_behavior))
+    }
+
+    pub fn lst_shift(&self, periods: i64) -> ListChunked {
+        self.apply_amortized(|s| s.as_ref().shift(periods))
+    }
+
+    pub fn lst_slice(&self, offset: i64, length: usize) -> ListChunked {
+        self.apply_amortized(|s| s.as_ref().slice(offset, length))
+    }
+
+    pub fn lst_lengths(&self) -> IdxCa {
         let mut lengths = Vec::with_capacity(self.len());
         self.downcast_iter().for_each(|arr| {
             let offsets = arr.offsets().as_slice();
             let mut last = offsets[0];
             for o in &offsets[1..] {
-                lengths.push((*o - last) as u32);
+                lengths.push((*o - last) as IdxSize);
                 last = *o;
             }
         });
-        UInt32Chunked::from_vec(self.name(), lengths)
+        IdxCa::from_vec(self.name(), lengths)
     }
 
     /// Get the value by index in the sublists.
