@@ -26,9 +26,7 @@ where
 
 /// Trimmed down object safe polars object
 pub trait PolarsObjectSafe: Any + Debug + Send + Sync + Display {
-    fn type_name(&self) -> &'static str
-    where
-        Self: Sized;
+    fn type_name(&self) -> &'static str;
 }
 
 /// Values need to implement this so that they can be stored into a Series and DataFrame
