@@ -1,7 +1,5 @@
 use crate::prelude::*;
 use crate::utils::{CustomIterTools, NoNull};
-#[cfg(feature = "dtype-categorical")]
-use std::ops::Deref;
 
 impl<T> ChunkReverse<T> for ChunkedArray<T>
 where
@@ -20,14 +18,6 @@ where
     }
 }
 
-#[cfg(feature = "dtype-categorical")]
-impl ChunkReverse<CategoricalType> for CategoricalChunked {
-    fn reverse(&self) -> ChunkedArray<CategoricalType> {
-        let ca: CategoricalChunked = self.deref().reverse().into();
-        ca.set_state(self)
-    }
-}
-
 macro_rules! impl_reverse {
     ($arrow_type:ident, $ca_type:ident) => {
         impl ChunkReverse<$arrow_type> for $ca_type {
