@@ -55,7 +55,13 @@ where
 }
 
 impl Series {
-    pub fn sample_n(&self, n: usize, with_replacement: bool, seed: Option<u64>) -> Result<Self> {
+    pub fn sample_n(
+        &self,
+        n: usize,
+        with_replacement: bool,
+        shuffle: bool,
+        seed: Option<u64>,
+    ) -> Result<Self> {
         if !with_replacement && n > self.len() {
             return Err(PolarsError::ShapeMisMatch(
                 "n is larger than the number of elements in this array".into(),
@@ -71,7 +77,7 @@ impl Series {
                 unsafe { self.take_unchecked(&idx) }
             }
             false => {
-                let idx = create_rand_index_no_replacement(n, len, seed, false);
+                let idx = create_rand_index_no_replacement(n, len, seed, shuffle);
                 // Safety we know that we never go out of bounds
                 debug_assert_eq!(len, self.len());
                 unsafe { self.take_unchecked(&idx) }
@@ -84,10 +90,11 @@ impl Series {
         &self,
         frac: f64,
         with_replacement: bool,
+        shuffle: bool,
         seed: Option<u64>,
     ) -> Result<Self> {
         let n = (self.len() as f64 * frac) as usize;
-        self.sample_n(n, with_replacement, seed)
+        self.sample_n(n, with_replacement, shuffle, seed)
     }
 
     pub fn shuffle(&self, seed: u64) -> Self {
@@ -105,7 +112,13 @@ where
     ChunkedArray<T>: ChunkTake,
 {
     /// Sample n datapoints from this ChunkedArray.
-    pub fn sample_n(&self, n: usize, with_replacement: bool, seed: Option<u64>) -> Result<Self> {
+    pub fn sample_n(
+        &self,
+        n: usize,
+        with_replacement: bool,
+        shuffle: bool,
+        seed: Option<u64>,
+    ) -> Result<Self> {
         if !with_replacement && n > self.len() {
             return Err(PolarsError::ShapeMisMatch(
                 "n is larger than the number of elements in this array".into(),
@@ -121,7 +134,7 @@ where
                 unsafe { Ok(self.take_unchecked((&idx).into())) }
             }
             false => {
-                let idx = create_rand_index_no_replacement(n, len, seed, false);
+                let idx = create_rand_index_no_replacement(n, len, seed, shuffle);
                 // Safety we know that we never go out of bounds
                 debug_assert_eq!(len, self.len());
                 unsafe { Ok(self.take_unchecked((&idx).into())) }
@@ -134,16 +147,23 @@ where
         &self,
         frac: f64,
         with_replacement: bool,
+        shuffle: bool,
         seed: Option<u64>,
     ) -> Result<Self> {
         let n = (self.len() as f64 * frac) as usize;
-        self.sample_n(n, with_replacement, seed)
+        self.sample_n(n, with_replacement, shuffle, seed)
     }
 }
 
 impl DataFrame {
     /// Sample n datapoints from this DataFrame.
-    pub fn sample_n(&self, n: usize, with_replacement: bool, seed: Option<u64>) -> Result<Self> {
+    pub fn sample_n(
+        &self,
+        n: usize,
+        with_replacement: bool,
+        shuffle: bool,
+        seed: Option<u64>,
+    ) -> Result<Self> {
         if !with_replacement && n > self.height() {
             return Err(PolarsError::ShapeMisMatch(
                 "n is larger than the number of elements in this array".into(),
@@ -152,7 +172,7 @@ impl DataFrame {
         // all columns should used the same indices. So we first create the indices.
         let idx = match with_replacement {
             true => create_rand_index_with_replacement(n, self.height(), seed),
-            false => create_rand_index_no_replacement(n, self.height(), seed, false),
+            false => create_rand_index_no_replacement(n, self.height(), seed, shuffle),
         };
         // Safety:
         // indices are within bounds
@@ -164,10 +184,11 @@ impl DataFrame {
         &self,
         frac: f64,
         with_replacement: bool,
+        shuffle: bool,
         seed: Option<u64>,
     ) -> Result<Self> {
         let n = (self.height() as f64 * frac) as usize;
-        self.sample_n(n, with_replacement, seed)
+        self.sample_n(n, with_replacement, shuffle, seed)
     }
 }
 
@@ -247,16 +268,16 @@ mod test {
         .unwrap();
 
         // default samples are random and don't require seeds
-        assert!(df.sample_n(3, false, None).is_ok());
-        assert!(df.sample_frac(0.4, false, None).is_ok());
+        assert!(df.sample_n(3, false, false, None).is_ok());
+        assert!(df.sample_frac(0.4, false, false, None).is_ok());
         // with seeding
-        assert!(df.sample_n(3, false, Some(0)).is_ok());
-        assert!(df.sample_frac(0.4, false, Some(0)).is_ok());
+        assert!(df.sample_n(3, false, false, Some(0)).is_ok());
+        assert!(df.sample_frac(0.4, false, false, Some(0)).is_ok());
         // without replacement can not sample more than 100%
-        assert!(df.sample_frac(2.0, false, Some(0)).is_err());
-        assert!(df.sample_n(3, true, Some(0)).is_ok());
-        assert!(df.sample_frac(0.4, true, Some(0)).is_ok());
+        assert!(df.sample_frac(2.0, false, false, Some(0)).is_err());
+        assert!(df.sample_n(3, true, false, Some(0)).is_ok());
+        assert!(df.sample_frac(0.4, true, false, Some(0)).is_ok());
         // with replacement can sample more than 100%
-        assert!(df.sample_frac(2.0, true, Some(0)).is_ok());
+        assert!(df.sample_frac(2.0, true, false, Some(0)).is_ok());
     }
 }
