@@ -25,7 +25,7 @@ impl Utf8Chunked {
     pub fn json_path_match(&self, json_path: &str) -> Result<Utf8Chunked> {
         match Compiled::compile(json_path) {
             Ok(pat) => Ok(self.apply_on_opt(|opt_s| opt_s.and_then(|s| extract_json(&pat, s)))),
-            Err(e) => Err(PolarsError::ValueError(
+            Err(e) => Err(PolarsError::ComputeError(
                 format!("error compiling JSONpath expression {:?}", e).into(),
             )),
         }
