@@ -3,6 +3,6 @@ pub use arrow;
 pub use chrono;
 
 #[cfg(feature = "private")]
-pub use lazy_static;
+pub use once_cell;
 #[cfg(feature = "private")]
 pub use rayon;
