@@ -3,9 +3,7 @@ use super::IntoSeries;
 use super::SeriesTrait;
 use super::SeriesWrap;
 use super::*;
-use crate::chunked_array::{
-    comparison::*, ops::explode::ExplodeByOffsets, AsSinglePtr, ChunkIdIter,
-};
+use crate::chunked_array::{comparison::*, ops::explode::ExplodeByOffsets, AsSinglePtr};
 use crate::fmt::FmtList;
 use crate::frame::{groupby::*, hash_join::*};
 use crate::prelude::*;
@@ -83,44 +81,26 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
         self.0.vec_hash_combine(build_hasher, hashes)
     }
 
-    fn agg_mean(&self, _groups: &GroupsProxy) -> Option<Series> {
-        // does not make sense on logical
-        None
-    }
-
-    fn agg_min(&self, groups: &GroupsProxy) -> Option<Series> {
+    fn agg_min(&self, groups: &GroupsProxy) -> Series {
         self.0
             .agg_min(groups)
-            .map(|ca| ca.into_duration(self.0.time_unit()).into_series())
+            .into_duration(self.0.time_unit())
+            .into_series()
     }
 
-    fn agg_max(&self, groups: &GroupsProxy) -> Option<Series> {
+    fn agg_max(&self, groups: &GroupsProxy) -> Series {
         self.0
             .agg_max(groups)
-            .map(|ca| ca.into_duration(self.0.time_unit()).into_series())
+            .into_duration(self.0.time_unit())
+            .into_series()
     }
 
-    fn agg_sum(&self, _groups: &GroupsProxy) -> Option<Series> {
-        // does not make sense on logical
-        None
-    }
-
-    fn agg_std(&self, _groups: &GroupsProxy) -> Option<Series> {
-        // does not make sense on logical
-        None
-    }
-
-    fn agg_var(&self, _groups: &GroupsProxy) -> Option<Series> {
-        // does not make sense on logical
-        None
-    }
-
-    fn agg_list(&self, groups: &GroupsProxy) -> Option<Series> {
+    fn agg_list(&self, groups: &GroupsProxy) -> Series {
         // we cannot cast and dispatch as the inner type of the list would be incorrect
-        self.0.agg_list(groups).map(|s| {
-            s.cast(&DataType::List(Box::new(self.dtype().clone())))
-                .unwrap()
-        })
+        self.0
+            .agg_list(groups)
+            .cast(&DataType::List(Box::new(self.dtype().clone())))
+            .unwrap()
     }
 
     fn agg_quantile(
@@ -128,16 +108,18 @@ impl private::PrivateSeries for SeriesWrap<DurationChunked> {
         groups: &GroupsProxy,
         quantile: f64,
         interpol: QuantileInterpolOptions,
-    ) -> Option<Series> {
+    ) -> Series {
         self.0
             .agg_quantile(groups, quantile, interpol)
-            .map(|s| s.into_duration(self.0.time_unit()).into_series())
+            .into_duration(self.0.time_unit())
+            .into_series()
     }
 
-    fn agg_median(&self, groups: &GroupsProxy) -> Option<Series> {
+    fn agg_median(&self, groups: &GroupsProxy) -> Series {
         self.0
             .agg_median(groups)
-            .map(|s| s.into_duration(self.0.time_unit()).into_series())
+            .into_duration(self.0.time_unit())
+            .into_series()
     }
 
     fn zip_outer_join_column(
@@ -309,6 +291,18 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
             .map(|ca| ca.into_duration(self.0.time_unit()).into_series())
     }
 
+    #[cfg(feature = "chunked_ids")]
+    unsafe fn _take_chunked_unchecked(&self, by: &[ChunkId]) -> Series {
+        let ca = self.0.deref().take_chunked_unchecked(by);
+        ca.into_duration(self.0.time_unit()).into_series()
+    }
+
+    #[cfg(feature = "chunked_ids")]
+    unsafe fn _take_opt_chunked_unchecked(&self, by: &[Option<ChunkId>]) -> Series {
+        let ca = self.0.deref().take_opt_chunked_unchecked(by);
+        ca.into_duration(self.0.time_unit()).into_series()
+    }
+
     fn take(&self, indices: &IdxCa) -> Result<Series> {
         ChunkTake::take(self.0.deref(), indices.into())
             .map(|ca| ca.into_duration(self.0.time_unit()).into_series())
@@ -372,10 +366,6 @@ impl SeriesTrait for SeriesWrap<DurationChunked> {
         self.0.cast(data_type)
     }
 
-    fn to_dummies(&self) -> Result<DataFrame> {
-        self.0.to_dummies()
-    }
-
     fn get(&self, index: usize) -> AnyValue {
         self.0.get_any_value(index)
     }
