@@ -35,7 +35,7 @@ use crate::chunked_array::{
         compare_inner::{IntoPartialEqInner, IntoPartialOrdInner, PartialEqInner, PartialOrdInner},
         explode::ExplodeByOffsets,
     },
-    AsSinglePtr, ChunkIdIter,
+    AsSinglePtr,
 };
 use crate::fmt::FmtList;
 use crate::frame::groupby::*;
@@ -172,19 +172,15 @@ macro_rules! impl_dyn_series {
                 self.0.vec_hash_combine(build_hasher, hashes)
             }
 
-            fn agg_mean(&self, groups: &GroupsProxy) -> Option<Series> {
-                self.0.agg_mean(groups)
-            }
-
-            fn agg_min(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_min(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_min(groups)
             }
 
-            fn agg_max(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_max(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_max(groups)
             }
 
-            fn agg_sum(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_sum(&self, groups: &GroupsProxy) -> Series {
                 use DataType::*;
                 match self.dtype() {
                     Int8 | UInt8 | Int16 | UInt16 => self.cast(&Int64).unwrap().agg_sum(groups),
@@ -192,15 +188,15 @@ macro_rules! impl_dyn_series {
                 }
             }
 
-            fn agg_std(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_std(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_std(groups)
             }
 
-            fn agg_var(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_var(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_var(groups)
             }
 
-            fn agg_list(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_list(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_list(groups)
             }
 
@@ -209,11 +205,11 @@ macro_rules! impl_dyn_series {
                 groups: &GroupsProxy,
                 quantile: f64,
                 interpol: QuantileInterpolOptions,
-            ) -> Option<Series> {
+            ) -> Series {
                 self.0.agg_quantile(groups, quantile, interpol)
             }
 
-            fn agg_median(&self, groups: &GroupsProxy) -> Option<Series> {
+            fn agg_median(&self, groups: &GroupsProxy) -> Series {
                 self.0.agg_median(groups)
             }
             fn zip_outer_join_column(
@@ -514,6 +510,16 @@ macro_rules! impl_dyn_series {
                 self.0.median()
             }
 
+            #[cfg(feature = "chunked_ids")]
+            unsafe fn _take_chunked_unchecked(&self, by: &[ChunkId]) -> Series {
+                self.0.take_chunked_unchecked(by).into_series()
+            }
+
+            #[cfg(feature = "chunked_ids")]
+            unsafe fn _take_opt_chunked_unchecked(&self, by: &[Option<ChunkId>]) -> Series {
+                self.0.take_opt_chunked_unchecked(by).into_series()
+            }
+
             fn take(&self, indices: &IdxCa) -> Result<Series> {
                 let indices = if indices.chunks.len() > 1 {
                     Cow::Owned(indices.rechunk())
@@ -569,10 +575,6 @@ macro_rules! impl_dyn_series {
                 self.0.cast(data_type)
             }
 
-            fn to_dummies(&self) -> Result<DataFrame> {
-                ToDummies::to_dummies(&self.0)
-            }
-
             fn get(&self, index: usize) -> AnyValue {
                 self.0.get_any_value(index)
             }
