@@ -3,13 +3,25 @@ use crate::prelude::*;
 use polars_arrow::kernels::list::array_to_unit_list;
 use std::borrow::Cow;
 
+fn reshape_fast_path(name: &str, s: &Series) -> Series {
+    let chunks = s
+        .chunks()
+        .iter()
+        .map(|arr| Arc::new(array_to_unit_list(arr.clone())) as ArrayRef)
+        .collect::<Vec<_>>();
+
+    let mut ca = ListChunked::from_chunks(name, chunks);
+    ca.set_fast_explode();
+    ca.into_series()
+}
+
 impl Series {
     /// Convert the values of this Series to a ListChunked with a length of 1,
     /// So a Series of:
     /// `[1, 2, 3]` becomes `[[1, 2, 3]]`
     pub fn to_list(&self) -> Result<ListChunked> {
         let s = self.rechunk();
-        let values = &s.chunks()[0];
+        let values = s.array_ref(0);
 
         let offsets = vec![0i64, values.len() as i64];
         let inner_type = self.dtype();
@@ -29,11 +41,21 @@ impl Series {
     }
 
     pub fn reshape(&self, dims: &[i64]) -> Result<Series> {
+        if dims.is_empty() {
+            panic!("dimensions cannot be empty")
+        }
         let s = if let DataType::List(_) = self.dtype() {
             Cow::Owned(self.explode()?)
         } else {
             Cow::Borrowed(self)
         };
+
+        // no rows
+        if dims[0] == 0 {
+            let s = reshape_fast_path(self.name(), &s);
+            return Ok(s);
+        }
+
         let s_ref = s.as_ref();
 
         let mut dims = dims.to_vec();
@@ -56,9 +78,6 @@ impl Series {
         }
 
         match dims.len() {
-            0 => {
-                panic!("dimensions cannot be empty")
-            }
             1 => Ok(s_ref.slice(0, dims[0] as usize)),
             2 => {
                 let mut rows = dims[0];
@@ -74,15 +93,8 @@ impl Series {
 
                 // fast path, we can create a unit list so we only allocate offsets
                 if rows as usize == s_ref.len() && cols == 1 {
-                    let chunks = s_ref
-                        .chunks()
-                        .iter()
-                        .map(|arr| Arc::new(array_to_unit_list(arr.clone())) as ArrayRef)
-                        .collect::<Vec<_>>();
-
-                    let mut ca = ListChunked::from_chunks(self.name(), chunks);
-                    ca.set_fast_explode();
-                    return Ok(ca.into_series());
+                    let s = reshape_fast_path(self.name(), s_ref);
+                    return Ok(s);
                 }
 
                 let mut builder =
