@@ -587,6 +587,19 @@ impl Expr {
         }
     }
 
+    fn map_private(self, function_expr: FunctionExpr, fmt_str: &'static str) -> Self {
+        Expr::Function {
+            input: vec![self],
+            function: function_expr,
+            options: FunctionOptions {
+                collect_groups: ApplyOptions::ApplyFlat,
+                input_wildcard_expansion: false,
+                auto_explode: false,
+                fmt_str,
+            },
+        }
+    }
+
     /// Apply a function/closure once the logical plan get executed with many arguments
     ///
     /// See the [`Expr::map`] function for the differences between [`map`](Expr::map) and [`apply`](Expr::apply).
@@ -631,7 +644,7 @@ impl Expr {
                 collect_groups: ApplyOptions::ApplyList,
                 input_wildcard_expansion: false,
                 auto_explode: false,
-                fmt_str: "",
+                fmt_str: "map_list",
             },
         }
     }
@@ -1077,11 +1090,7 @@ impl Expr {
 
     /// Raise expression to the power `exponent`
     pub fn pow(self, exponent: f64) -> Self {
-        self.map(
-            move |s: Series| s.pow(exponent),
-            GetOutput::from_type(DataType::Float64),
-        )
-        .with_fmt("pow")
+        self.map_private(FunctionExpr::Pow(exponent), "pow")
     }
 
     /// Filter a single column
@@ -1636,9 +1645,15 @@ impl Expr {
     }
 
     #[cfg(feature = "random")]
-    pub fn sample_frac(self, frac: f64, with_replacement: bool, seed: Option<u64>) -> Self {
+    pub fn sample_frac(
+        self,
+        frac: f64,
+        with_replacement: bool,
+        shuffle: bool,
+        seed: Option<u64>,
+    ) -> Self {
         self.apply(
-            move |s| s.sample_frac(frac, with_replacement, seed),
+            move |s| s.sample_frac(frac, with_replacement, shuffle, seed),
             GetOutput::same_type(),
         )
         .with_fmt("shuffle")
@@ -1795,9 +1810,9 @@ impl Expr {
     #[cfg_attr(docsrs, doc(cfg(feature = "log")))]
     /// Compute the entropy as `-sum(pk * log(pk)`.
     /// where `pk` are discrete probabilities.
-    pub fn entropy(self, base: f64) -> Self {
+    pub fn entropy(self, base: f64, normalize: bool) -> Self {
         self.apply(
-            move |s| Ok(Series::new(s.name(), [s.entropy(base)])),
+            move |s| Ok(Series::new(s.name(), [s.entropy(base, normalize)])),
             GetOutput::map_dtype(|dt| {
                 if matches!(dt, DataType::Float32) {
                     DataType::Float32
@@ -1821,6 +1836,12 @@ impl Expr {
             })
     }
 
+    #[cfg(feature = "row_hash")]
+    /// Compute the hash of every element
+    pub fn hash(self, seed: usize) -> Expr {
+        self.map_private(FunctionExpr::Hash(seed), "hash")
+    }
+
     #[cfg(feature = "strings")]
     pub fn str(self) -> string::StringNameSpace {
         string::StringNameSpace(self)
