@@ -5,6 +5,8 @@ mod csv;
 mod ipc;
 #[cfg(feature = "parquet")]
 mod parquet;
+#[cfg(feature = "python")]
+mod python;
 
 #[cfg(feature = "csv-file")]
 pub use csv::*;
@@ -42,6 +44,7 @@ use crate::prelude::{
 };
 
 use crate::logical_plan::FETCH_ROWS;
+use crate::prelude::delay_rechunk::DelayRechunk;
 use crate::utils::{combine_predicates_expr, expr_to_root_column_names};
 use polars_arrow::prelude::QuantileInterpolOptions;
 use polars_core::frame::explode::MeltArgs;
@@ -162,6 +165,27 @@ impl LazyFrame {
         (root, expr_arena, lp_arena)
     }
 
+    /// Set allowed optimizations
+    pub fn with_optimizations(mut self, opt_state: OptState) -> Self {
+        self.opt_state = opt_state;
+        self
+    }
+
+    /// Turn off all optimizations
+    pub fn without_optimizations(self) -> Self {
+        self.with_optimizations(OptState {
+            projection_pushdown: false,
+            predicate_pushdown: false,
+            type_coercion: true,
+            simplify_expr: false,
+            global_string_cache: false,
+            slice_pushdown: false,
+            // will be toggled by a scan operation such as csv scan or parquet scan
+            agg_scan_projection: false,
+            aggregate_pushdown: false,
+        })
+    }
+
     /// Toggle projection pushdown optimization.
     pub fn with_projection_pushdown(mut self, toggle: bool) -> Self {
         self.opt_state.projection_pushdown = toggle;
@@ -289,7 +313,17 @@ impl LazyFrame {
         self.select_local(vec![col("*").reverse()])
     }
 
-    fn rename_impl_swapping(self, existing: Vec<String>, new: Vec<String>) -> Self {
+    fn rename_impl_swapping(self, mut existing: Vec<String>, mut new: Vec<String>) -> Self {
+        assert_eq!(new.len(), existing.len());
+        for idx in 0..existing.len() {
+            // remove "name" -> "name"
+            // these are no ops.
+            if existing[idx] == new[idx] {
+                existing.swap_remove(idx);
+                new.swap_remove(idx);
+            }
+        }
+
         // schema after renaming
         let mut new_schema = (&*self.schema()).clone();
 
@@ -534,6 +568,7 @@ impl LazyFrame {
         }
         // make sure its before slice pushdown.
         rules.push(Box::new(FastProjection {}));
+        rules.push(Box::new(DelayRechunk {}));
 
         if slice_pushdown {
             let slice_pushdown_opt = SlicePushDown {};
