@@ -448,6 +448,11 @@ impl PredicatePushDown {
             | lp @ Aggregate {..} => {
                 self.no_pushdown_restart_opt(lp, acc_predicates, lp_arena, expr_arena)
             }
+            #[cfg(feature = "python")]
+            // python node does not yet support predicates
+             lp @ PythonScan {..} => {
+                self.no_pushdown_restart_opt(lp, acc_predicates, lp_arena, expr_arena)
+            }
         }
     }
 
