@@ -48,6 +48,18 @@ fn use_supertype(
             // do nothing
             _ => {}
         }
+    } else {
+        use DataType::*;
+        match (type_left, type_right, left, right) {
+            // if the we compare a categorical to a literal string we want to cast the literal to categorical
+            #[cfg(feature = "dtype-categorical")]
+            (Categorical(_), Utf8, _, AExpr::Literal(_))
+            | (Utf8, Categorical(_), AExpr::Literal(_), _) => {
+                st = DataType::Categorical(None);
+            }
+            // do nothing
+            _ => {}
+        }
     }
     st
 }
@@ -150,10 +162,28 @@ impl OptimizationRule for TypeCoercionRule {
 
                     let type_left = left
                         .get_type(input_schema, Context::Default, expr_arena)
-                        .expect("could not get dtype");
+                        .ok()?;
                     let type_right = right
                         .get_type(input_schema, Context::Default, expr_arena)
-                        .expect("could not get dtype");
+                        .ok()?;
+
+                    // don't coerce string with number comparisons. They must error
+                    match (&type_left, &type_right, op) {
+                        #[cfg(not(feature = "dtype-categorical"))]
+                        (DataType::Utf8, dt, op) | (dt, DataType::Utf8, op)
+                            if op.is_comparison() && dt.is_numeric() =>
+                        {
+                            return None
+                        }
+                        #[cfg(feature = "dtype-categorical")]
+                        (DataType::Utf8 | DataType::Categorical(_), dt, op)
+                        | (dt, DataType::Utf8 | DataType::Categorical(_), op)
+                            if op.is_comparison() && dt.is_numeric() =>
+                        {
+                            return None
+                        }
+                        _ => {}
+                    }
 
                     #[allow(unused_mut, unused_assignments)]
                     let mut compare_cat_to_string = false;
@@ -183,6 +213,53 @@ impl OptimizationRule for TypeCoercionRule {
                                 | (DataType::Duration(_), DataType::Date)
                         );
 
+                    let list_arithmetic = op.is_arithmetic()
+                        && matches!(
+                            (&type_left, &type_right),
+                            (DataType::List(_), _) | (_, DataType::List(_))
+                        );
+
+                    // Special path for list arithmetic
+                    if list_arithmetic {
+                        match (&type_left, &type_right) {
+                            (DataType::List(inner), _) => {
+                                return if type_right != **inner {
+                                    let new_node_right = expr_arena.add(AExpr::Cast {
+                                        expr: node_right,
+                                        data_type: *inner.clone(),
+                                        strict: false,
+                                    });
+
+                                    Some(AExpr::BinaryExpr {
+                                        left: node_left,
+                                        op,
+                                        right: new_node_right,
+                                    })
+                                } else {
+                                    None
+                                };
+                            }
+                            (_, DataType::List(inner)) => {
+                                return if type_left != **inner {
+                                    let new_node_left = expr_arena.add(AExpr::Cast {
+                                        expr: node_left,
+                                        data_type: *inner.clone(),
+                                        strict: false,
+                                    });
+
+                                    Some(AExpr::BinaryExpr {
+                                        left: new_node_left,
+                                        op,
+                                        right: node_right,
+                                    })
+                                } else {
+                                    None
+                                };
+                            }
+                            _ => unreachable!(),
+                        }
+                    }
+
                     if type_left == type_right || compare_cat_to_string || datetime_arithmetic {
                         None
                     } else {
