@@ -1,5 +1,4 @@
 use crate::physical_plan::state::ExecutionState;
-use crate::physical_plan::PhysicalAggregation;
 use crate::prelude::*;
 use polars_core::frame::groupby::GroupsProxy;
 use polars_core::series::unstable::UnstableSeries;
@@ -286,8 +285,15 @@ impl PhysicalExpr for BinaryExpr {
                     let lhs = ac_l.aggregated();
                     ac_l.with_update_groups(UpdateGroups::WithSeriesLenOwned(lhs.clone()));
 
+                    // we should only explode lists
+                    // not aggregated flat states
+                    let flatten = |s: Series| match s.dtype() {
+                        DataType::List(_) => s.explode(),
+                        _ => Ok(s),
+                    };
+
                     let out =
-                        apply_operator(&lhs.explode()?, &ac_r.aggregated().explode()?, self.op)?;
+                        apply_operator(&flatten(lhs)?, &flatten(ac_r.aggregated())?, self.op)?;
                     ac_l.with_series(out, false);
                     Ok(ac_l)
                 } else {
@@ -309,17 +315,16 @@ impl PhysicalExpr for BinaryExpr {
         self.expr.to_field(input_schema, Context::Default)
     }
 
-    fn as_agg_expr(&self) -> Result<&dyn PhysicalAggregation> {
-        Ok(self)
+    fn as_partitioned_aggregator(&self) -> Option<&dyn PartitionedAggregation> {
+        Some(self)
     }
+
     #[cfg(feature = "parquet")]
     fn as_stats_evaluator(&self) -> Option<&dyn polars_io::predicates::StatsEvaluator> {
         Some(self)
     }
 }
 
-impl PhysicalAggregation for BinaryExpr {}
-
 #[cfg(feature = "parquet")]
 mod stats {
     use super::*;
@@ -443,6 +448,8 @@ mod stats {
                     match l.to_min_max() {
                         None => Ok(true),
                         Some(min_max_s) => {
+                            // will be incorrect if not
+                            debug_assert_eq!(min_max_s.null_count(), 0);
                             let lit_s = self.right.evaluate(&dummy, &state).unwrap();
                             Ok(apply_operator_stats_rhs_lit(&min_max_s, &lit_s, self.op))
                         }
@@ -453,6 +460,8 @@ mod stats {
                     match r.to_min_max() {
                         None => Ok(true),
                         Some(min_max_s) => {
+                            // will be incorrect if not
+                            debug_assert_eq!(min_max_s.null_count(), 0);
                             let lit_s = self.left.evaluate(&dummy, &state).unwrap();
                             Ok(apply_operator_stats_lhs_lit(&lit_s, &min_max_s, self.op))
                         }
@@ -492,3 +501,27 @@ mod stats {
         }
     }
 }
+
+impl PartitionedAggregation for BinaryExpr {
+    fn evaluate_partitioned(
+        &self,
+        df: &DataFrame,
+        groups: &GroupsProxy,
+        state: &ExecutionState,
+    ) -> Result<Series> {
+        let left = self.left.as_partitioned_aggregator().unwrap();
+        let right = self.right.as_partitioned_aggregator().unwrap();
+        let left = left.evaluate_partitioned(df, groups, state)?;
+        let right = right.evaluate_partitioned(df, groups, state)?;
+        apply_operator(&left, &right, self.op)
+    }
+
+    fn finalize(
+        &self,
+        partitioned: Series,
+        _groups: &GroupsProxy,
+        _state: &ExecutionState,
+    ) -> Result<Series> {
+        Ok(partitioned)
+    }
+}
