@@ -5,10 +5,14 @@ use polars_core::frame::groupby::GroupsProxy;
 use polars_core::prelude::*;
 use polars_core::POOL;
 
+#[cfg(feature = "serde")]
+use serde::{Deserialize, Serialize};
+
 #[repr(transparent)]
 struct Wrap<T>(pub T);
 
 #[derive(Clone, Debug)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct DynamicGroupOptions {
     /// Time or index column
     pub index_column: String,
@@ -26,6 +30,7 @@ pub struct DynamicGroupOptions {
 }
 
 #[derive(Clone, Debug)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct RollingGroupOptions {
     /// Time or index column
     pub index_column: String,
@@ -436,7 +441,7 @@ mod test {
                     },
                 )
                 .unwrap();
-            let sum = a.agg_sum(&groups).unwrap();
+            let sum = a.agg_sum(&groups);
             let expected = Series::new("", [3, 10, 15, 24, 11, 1]);
             assert_eq!(sum, expected);
         }
