@@ -1,3 +1,4 @@
+use crate::arrow_interop::to_rust::pyarrow_schema_to_rust;
 use crate::conversion::Wrap;
 use crate::dataframe::PyDataFrame;
 use crate::error::PyPolarsErr;
@@ -16,7 +17,7 @@ use polars_core::prelude::{
 };
 use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
-use pyo3::types::PyList;
+use pyo3::types::{PyDict, PyList};
 use std::io::BufWriter;
 
 #[pyclass]
@@ -144,7 +145,7 @@ impl PyLazyFrame {
         rechunk: bool,
         skip_rows_after_header: usize,
         encoding: &str,
-        row_count: Option<(String, u32)>,
+        row_count: Option<(String, IdxSize)>,
         parse_dates: bool,
     ) -> PyResult<Self> {
         let null_values = null_values.map(|w| w.0);
@@ -223,7 +224,7 @@ impl PyLazyFrame {
         cache: bool,
         parallel: bool,
         rechunk: bool,
-        row_count: Option<(String, u32)>,
+        row_count: Option<(String, IdxSize)>,
     ) -> PyResult<Self> {
         let row_count = row_count.map(|(name, offset)| RowCount { name, offset });
         let args = ScanArgsParquet {
@@ -243,7 +244,7 @@ impl PyLazyFrame {
         n_rows: Option<usize>,
         cache: bool,
         rechunk: bool,
-        row_count: Option<(String, u32)>,
+        row_count: Option<(String, IdxSize)>,
     ) -> PyResult<Self> {
         let row_count = row_count.map(|(name, offset)| RowCount { name, offset });
         let args = ScanArgsIpc {
@@ -256,6 +257,12 @@ impl PyLazyFrame {
         Ok(lf.into())
     }
 
+    #[staticmethod]
+    pub fn scan_from_python_function(schema: &PyList, scan_fn: Vec<u8>) -> PyResult<Self> {
+        let schema = pyarrow_schema_to_rust(schema)?;
+        Ok(LazyFrame::scan_from_python_function(schema, scan_fn).into())
+    }
+
     pub fn describe_plan(&self) -> String {
         self.ldf.describe_plan()
     }
@@ -663,7 +670,7 @@ impl PyLazyFrame {
         ldf.melt(args).into()
     }
 
-    pub fn with_row_count(&self, name: &str, offset: Option<u32>) -> Self {
+    pub fn with_row_count(&self, name: &str, offset: Option<IdxSize>) -> Self {
         let ldf = self.ldf.clone();
         ldf.with_row_count(name, offset).into()
     }
@@ -716,6 +723,26 @@ impl PyLazyFrame {
         self.ldf.schema().iter_names().cloned().collect()
     }
 
+    pub fn dtypes(&self, py: Python) -> PyObject {
+        let schema = self.ldf.schema();
+        let iter = schema
+            .iter_dtypes()
+            .map(|dt| Wrap(dt.clone()).to_object(py));
+        PyList::new(py, iter).to_object(py)
+    }
+
+    pub fn schema(&self, py: Python) -> PyObject {
+        let schema = self.ldf.schema();
+        let schema_dict = PyDict::new(py);
+
+        schema.iter_fields().for_each(|fld| {
+            schema_dict
+                .set_item(fld.name(), Wrap(fld.data_type().clone()))
+                .unwrap()
+        });
+        schema_dict.to_object(py)
+    }
+
     pub fn unnest(&self, cols: Vec<String>) -> PyLazyFrame {
         self.ldf.clone().unnest(cols).into()
     }
