@@ -10,6 +10,7 @@ use polars::lazy::dsl::Operator;
 use polars::prelude::*;
 use polars_core::prelude::QuantileInterpolOptions;
 use pyo3::class::basic::CompareOp;
+use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
 use pyo3::types::{PyBool, PyBytes, PyFloat, PyInt, PyString};
 use std::borrow::Cow;
@@ -889,16 +890,6 @@ impl PyExpr {
     pub fn dot(&self, other: PyExpr) -> PyExpr {
         self.inner.clone().dot(other.inner).into()
     }
-    pub fn hash(&self, k0: u64, k1: u64, k2: u64, k3: u64) -> PyExpr {
-        let function = move |s: Series| {
-            let hb = ahash::RandomState::with_seeds(k0, k1, k2, k3);
-            Ok(s.hash(hb).into_series())
-        };
-        self.clone()
-            .inner
-            .map(function, GetOutput::from_type(DataType::UInt64))
-            .into()
-    }
 
     pub fn reinterpret(&self, signed: bool) -> PyExpr {
         let function = move |s: Series| reinterpret(&s, signed);
@@ -1184,6 +1175,34 @@ impl PyExpr {
         self.inner.clone().arr().eval(expr.inner, parallel).into()
     }
 
+    fn lst_to_struct(&self, width_strat: &str, name_gen: Option<PyObject>) -> PyResult<Self> {
+        let n_fields = match width_strat {
+            "first_non_null" => ListToStructWidthStrategy::FirstNonNull,
+            "max_width" => ListToStructWidthStrategy::MaxWidth,
+            strat => {
+                return Err(PyValueError::new_err(format!(
+                "strategy: {strat} not allowed, choose any of {{ 'first_non_null', 'max_width' }}"
+            )))
+            }
+        };
+
+        let name_gen = name_gen.map(|lambda| {
+            Arc::new(move |idx: usize| {
+                Python::with_gil(|py| {
+                    let out = lambda.call1(py, (idx,)).unwrap();
+                    out.extract::<String>(py).unwrap()
+                })
+            }) as NameGenerator
+        });
+
+        Ok(self
+            .inner
+            .clone()
+            .arr()
+            .to_struct(n_fields, name_gen)
+            .into())
+    }
+
     fn rank(&self, method: &str, reverse: bool) -> Self {
         let method = str_to_rankmethod(method).unwrap();
         let options = RankOptions {
@@ -1266,10 +1285,16 @@ impl PyExpr {
         self.inner.clone().shuffle(seed).into()
     }
 
-    pub fn sample_frac(&self, frac: f64, with_replacement: bool, seed: Option<u64>) -> Self {
+    pub fn sample_frac(
+        &self,
+        frac: f64,
+        with_replacement: bool,
+        shuffle: bool,
+        seed: Option<u64>,
+    ) -> Self {
         self.inner
             .clone()
-            .sample_frac(frac, with_replacement, seed)
+            .sample_frac(frac, with_replacement, shuffle, seed)
             .into()
     }
 
@@ -1333,8 +1358,11 @@ impl PyExpr {
         self.inner.clone().log(base).into()
     }
 
-    pub fn entropy(&self, base: f64) -> Self {
-        self.inner.clone().entropy(base).into()
+    pub fn entropy(&self, base: f64, normalize: bool) -> Self {
+        self.inner.clone().entropy(base, normalize).into()
+    }
+    pub fn hash(&self, seed: usize) -> Self {
+        self.inner.clone().hash(seed).into()
     }
 }
 
