@@ -79,6 +79,10 @@ def df() -> pl.DataFrame:
             "date": [1324, 123, 1234],
             "datetime": [13241324, 12341256, 12341234],
             "time": [13241324, 12341256, 12341234],
+            "list_str": [["a", "b", None], ["a"], []],
+            "list_bool": [[True, False, None], [None], []],
+            "list_int": [[1, None, 3], [None], []],
+            "list_flt": [[1.0, None, 3.0], [None], []],
         }
     )
     return df.with_columns(
@@ -91,6 +95,13 @@ def df() -> pl.DataFrame:
     )
 
 
+@pytest.fixture
+def df_no_lists(df: pl.DataFrame) -> pl.DataFrame:
+    return df.select(
+        pl.all().exclude(["list_str", "list_int", "list_bool", "list_int", "list_flt"])
+    )
+
+
 @pytest.fixture
 def fruits_cars() -> pl.DataFrame:
     return pl.DataFrame(
