@@ -44,3 +44,8 @@ def test_not_found_error() -> None:
     df = pl.read_csv(io.StringIO(csv))
     with pytest.raises(pl.NotFoundError):
         df.select("d")
+
+
+def test_string_numeric_comp_err() -> None:
+    with pytest.raises(pl.ComputeError, match="cannot compare Utf8 with numeric data"):
+        pl.DataFrame({"a": [1.1, 21, 31, 21, 51, 61, 71, 81]}).select(pl.col("a") < "9")
