@@ -1,3 +1,4 @@
+import typing
 from datetime import datetime
 from typing import Dict, Sequence, Type, Union
 
@@ -259,7 +260,7 @@ def test_from_pandas_dataframe() -> None:
     df = pl.from_pandas(pd_df)
     assert df.shape == (2, 3)
 
-    # if not a Pandas dataframe, raise a ValueError
+    # if not a pandas dataframe, raise a ValueError
     with pytest.raises(ValueError):
         _ = pl.from_pandas([1, 2])  # type: ignore
 
@@ -367,3 +368,12 @@ def test_from_pandas_ns_resolution() -> None:
         columns=["date"],
     )
     assert pl.from_pandas(df)[0, 0] == datetime(2021, 1, 1, 1, 0, 1)
+
+
+@typing.no_type_check
+def test_pandas_string_none_conversion_3298() -> None:
+    data = {"col_1": ["a", "b", "c", "d"]}
+    data["col_1"][0] = None
+    df_pd = pd.DataFrame(data)
+    df_pl = pl.DataFrame(df_pd)
+    assert df_pl.to_series().to_list() == [None, "b", "c", "d"]
